**********************************
  The :mod:`htsql_pgsql` package
**********************************

.. automodule:: htsql_pgsql
   :members:
.. automodule:: htsql_pgsql.connect
   :members:
.. automodule:: htsql_pgsql.domain
   :members:
.. automodule:: htsql_pgsql.export
   :members:
.. automodule:: htsql_pgsql.introspect
   :members:
.. automodule:: htsql_pgsql.split_sql
   :members:

